[tor-commits] [bridgedb/develop] Pep8 and docstring cleanup for bridgedb.Bridges.get_hmac().

isis at torproject.org isis at torproject.org
Sun Mar 16 16:38:45 UTC 2014


commit 194abedd7a842aeb99dbeac9f33bde0daf29f8e7
Author: Isis Lovecruft <isis at torproject.org>
Date:   Fri Mar 7 16:22:12 2014 +0000

    Pep8 and docstring cleanup for bridgedb.Bridges.get_hmac().
---
 lib/bridgedb/Bridges.py |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/bridgedb/Bridges.py b/lib/bridgedb/Bridges.py
index 531a842..3d27ad1 100644
--- a/lib/bridgedb/Bridges.py
+++ b/lib/bridgedb/Bridges.py
@@ -87,9 +87,9 @@ def is_valid_fingerprint(fp):
 toHex = binascii.b2a_hex
 fromHex = binascii.a2b_hex
 
-def get_hmac(k,v):
-    """Return the hmac of v using the key k."""
-    h = hmac.new(k, v, digestmod=DIGESTMOD)
+def get_hmac(key, value):
+    """Return the hmac of **value** using the **key**."""
+    h = hmac.new(key, value, digestmod=DIGESTMOD)
     return h.digest()
 
 def get_hmac_fn(k, hex=True):





More information about the tor-commits mailing list